
ฟังก์ชันของ Can Thitipong <br>
เพื่อทดสอบการใช้งาน upload library 

### All function

csv_read(path): read 'titanic_dataset.csv' file and convert to pandas dataframe

easy_plot(df): Plot **age** of passenger in Titanic in **histogram**

gender_pie_plot(df): Plot **gender** of passenger in **pie chart**

gender_bar_plot(df): Plot **gender** of passenger in **bar chart**

survived_plot(df): Plot **Number of suvived passenger** in **pie chart**

class_plot(df): Plot number of passenger in each ticket class in bar chart

class_survived(df): return table of survived number in eash class

bar_plot(df,variable): pass in dataframe and variable you want to plot in bar chart

plot_hist(df,variable): pass in dataframe and variable you want to plot in histogram